pub struct NagumoSatoMapBatchResult {
pub y: Vec<f64>,
pub x: Vec<u8>,
pub spikes: Vec<u8>,
pub y_final: f64,
pub x_final: u8,
pub spike_count: usize,
}Expand description
Complete state/output trajectory and final receipts for one atomic batch.
Fields
y: Vec<f64>Internal state after every step.
x: Vec<u8>All-or-none output after every step.
spikes: Vec<u8>Event alias of the all-or-none output.
y_final: f64Final internal state, or the initial state for an empty batch.
x_final: u8Final all-or-none output.
spike_count: usizeNumber of firing outputs in the batch.